/*
 * Copyright (C) 2018 Magnus Bergman <magnus.bergman@snisurset.net>
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, see <http:/www.gnu.org/licenses/>
 */
#include <stdlib.h>
#include <string.h>

#include "abydos.h"

/**
 * SECTION: abydos-util
 * @short_description: A few conveniency functions.
 * @title: Utility
 * @include: abydos.h
 **/


abydos_t *
abydos_create_from_file(const char *mime_type, const char *filename)
{
    abydos_t *ar = abydos_create(mime_type);
    if(!ar)
        return NULL;
    if(abydos_from_file(ar,filename) < 0){
        abydos_destroy(ar);
        return NULL;
    }
    return ar;
}


cairo_surface_t *
abydos_load(const char *mime_type, const char *filename)
{
    abydos_t *ar;
    cairo_surface_t *surface;
    if(!strcasecmp(mime_type,"image/png"))
        return cairo_image_surface_create_from_png (filename);
    ar = abydos_create_from_file(mime_type, filename);
    if(!ar)
        return NULL;
    surface = abydos_get_image_surface(ar, ABYDOS_GROW_TO_ASPECT_RATIO);
    abydos_destroy(ar);
    return surface;
}
